---
name: Question
about: Ask a question about the ONNX.
title: ''
labels: 'question'
assignees: ''

 

---
# Ask a Question

### Question
Explain your question here.

### Further information
- Relevant Area (*e.g. model usage, backend, best practices, converters, shape_inference, version_converter, training, test, operators*): 

- Is this issue related to a specific model?  
**Model name** (*e.g. mnist*):  
**Model opset** (*e.g. 7*):

### Notes
Any additional information, code snippets.
